@@ -12,7 +12,7 @@ class Keystone(monasca_setup.detection.ServicePlugin):
             'template_dir': template_dir,
             'overwrite': overwrite,
             'service_name': 'identity-service',
-            'process_names': ['keystone-all'],
+            'process_names': ['keystone-'],
             'service_api_url': 'http://localhost:35357/v3',
             'search_pattern': '.*v3.0.*'
         }
